==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/public/ec_rider/javascripts/application.js <==
// 読み込み中表示
function showLoading() {
    $('loading').show();
}

// 読み込み中表示終了
function hideLoading() {
    $('loading').hide();
}

// カレンダー
YAHOO.namespace("myCalendar");  
function getInitDoc(form_id, conteiner_id){
    return function () {
        YAHOO.myCalendar[form_id+"_" + conteiner_id + "_cal"] = new YAHOO.widget.Calendar("cal1",conteiner_id, {
            title:"日付を選択してください",
            close:true
        } );
        initCalObj(YAHOO.myCalendar[form_id+"_" + conteiner_id + "_cal"], form_id, conteiner_id);
    }
}
function initCalObj(cal, form_id, conteiner_id) {
    cal.selectEvent.subscribe(getHandleSelect(form_id, conteiner_id), cal, true);
   
    cal.cfg.setProperty("MDY_YEAR_POSITION", 1);
    cal.cfg.setProperty("MDY_MONTH_POSITION", 2);
    cal.cfg.setProperty("MDY_DAY_POSITION", 3);
   
    cal.cfg.setProperty("MY_YEAR_POSITION", 1);
    cal.cfg.setProperty("MY_MONTH_POSITION", 2);
   
    cal.cfg.setProperty("MONTHS_SHORT",   ["1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"]);
    cal.cfg.setProperty("MONTHS_LONG",    ["1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"]);
    cal.cfg.setProperty("WEEKDAYS_1CHAR", ["日", "月", "火", "水", "木", "金", "土"]);
    cal.cfg.setProperty("WEEKDAYS_SHORT", ["日", "月", "火", "水", "木", "金", "土"]);
    cal.cfg.setProperty("WEEKDAYS_MEDIUM",["日", "月", "火", "水", "木", "金", "土"]);
    cal.cfg.setProperty("WEEKDAYS_LONG",  ["日", "月", "火", "水", "木", "金", "土"]);
    cal.render();
     
    YAHOO.util.Event.addListener("txtDate", "focus", getHandleFocus(conteiner_id), cal, true);
}
function getHandleFocus(conteiner_id){
    return function (type, args, obj) {
        $(conteiner_id).show();
    }
}
function getHandleSelect(form_id, conteiner_id){
    return function (type,args,obj) {
        var dates = args[0];
        var date = dates[0];
        var year = date[0], month = date[1], day = date[2];

        var txtDate = document.getElementById(form_id);
        txtDate.value = year + "/" + month + "/" + day;
        $(conteiner_id).hide();
    }
}

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/public/ec_rider/javascripts/application.js <==
// 読み込み中表示
function showLoading() {
    $('loading').show();
}

// 読み込み中表示終了
function hideLoading() {
    $('loading').hide();
}

// カレンダー
YAHOO.namespace("myCalendar");  
function getInitDoc(form_id, conteiner_id, type){
    return function () {
        YAHOO.myCalendar[form_id+"_" + conteiner_id + "_cal"] = new YAHOO.widget.Calendar("cal1",conteiner_id, {
            title:"日付を選択してください",
            close:true
        } );
        initCalObj(YAHOO.myCalendar[form_id+"_" + conteiner_id + "_cal"], form_id, conteiner_id, type);
    }
}
function initCalObj(cal, form_id, conteiner_id, type) {
    cal.selectEvent.subscribe(getHandleSelect(form_id, conteiner_id, type), cal, true);
   
    cal.cfg.setProperty("MDY_YEAR_POSITION", 1);
    cal.cfg.setProperty("MDY_MONTH_POSITION", 2);
    cal.cfg.setProperty("MDY_DAY_POSITION", 3);
   
    cal.cfg.setProperty("MY_YEAR_POSITION", 1);
    cal.cfg.setProperty("MY_MONTH_POSITION", 2);
   
    cal.cfg.setProperty("MONTHS_SHORT",   ["1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"]);
    cal.cfg.setProperty("MONTHS_LONG",    ["1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"]);
    cal.cfg.setProperty("WEEKDAYS_1CHAR", ["日", "月", "火", "水", "木", "金", "土"]);
    cal.cfg.setProperty("WEEKDAYS_SHORT", ["日", "月", "火", "水", "木", "金", "土"]);
    cal.cfg.setProperty("WEEKDAYS_MEDIUM",["日", "月", "火", "水", "木", "金", "土"]);
    cal.cfg.setProperty("WEEKDAYS_LONG",  ["日", "月", "火", "水", "木", "金", "土"]);
    cal.render();
     
    YAHOO.util.Event.addListener("txtDate", "focus", getHandleFocus(conteiner_id), cal, true);
}
function getHandleFocus(conteiner_id){
    return function (type, args, obj) {
        $(conteiner_id).show();
    }
}
function getHandleSelect(form_id, conteiner_id, type){
    return function (type,args,obj) {
        var dates = args[0];
        var date = dates[0];
        var year = date[0], month = date[1], day = date[2];

        var txtDate = document.getElementById(form_id);
        if (type == 'md') {
            txtDate.value = month + "/" + day;
        } else {
            txtDate.value = year + "/" + month + "/" + day;
        }
        $(conteiner_id).hide();
    }
}
